// -*- C++ -*-

/* 
 * GChemPaint residues plugin
 * plugin.h 
 *
 * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GCHEMPAINT_RESIDUES_PLUGIN_H
#define GCHEMPAINT_RESIDUES_PLUGIN_H

#include <gcp/plugin.h>
#include <libxml/tree.h>

namespace gcp {
	class Application;
	class Residue;
}

class gcpResiduesPlugin: public gcp::Plugin
{
public:
	gcpResiduesPlugin ();
	virtual ~gcpResiduesPlugin ();

	void Populate (gcp::Application* App);
	void OpenDialog ();
	void OnNewResidue (gcp::Residue *res);

private:
	void ParseNodes (xmlNodePtr node, bool writeable);

private:
	gcp::Application *m_App;
};

#endif //GCHEMPAINT_RESIDUES_PLUGIN_H
